@@ -1,6 +1,6 @@
 from django.conf.urls import patterns, url
 
-from .views import ArchivePostListView, PostListView, PostDetail
+from .views import ArchivePostListView, PostListView, PostDetail, CategoryPostListView
 
 urlpatterns = patterns('',
     url(
@@ -22,11 +22,17 @@ urlpatterns = patterns('',
     ),
 
     url(
-        regex=r'^(?P<year>\d+)$',
+        regex=r'^(?P<year>\d+)/$',
         view=ArchivePostListView.as_view(),
         name='hermes_archive_year',
     ),
 
+    url(
+        regex=r'categories/(?P<slug>.+)/$',
+        view=CategoryPostListView.as_view(),
+        name='hermes_category_post_list',
+    ),
+
     url(
         regex=r'^$',
         view=PostListView.as_view(),
